@@ -4,6 +4,7 @@ from __future__ import absolute_import
 
 # import apis into api package
 from extremecloudiq.api.account_api import AccountApi
+from extremecloudiq.api.alert_api import AlertApi
 from extremecloudiq.api.application_api import ApplicationApi
 from extremecloudiq.api.authentication_api import AuthenticationApi
 from extremecloudiq.api.authorization_api import AuthorizationApi
@@ -14,6 +15,8 @@ from extremecloudiq.api.configuration___certificate_api import ConfigurationCert
 from extremecloudiq.api.configuration___deployment_api import ConfigurationDeploymentApi
 from extremecloudiq.api.configuration___policy_api import ConfigurationPolicyApi
 from extremecloudiq.api.configuration___user_management_api import ConfigurationUserManagementApi
+from extremecloudiq.api.copilot___anomalies_api import CopilotAnomaliesApi
+from extremecloudiq.api.copilot___connectivity_experience_api import CopilotConnectivityExperienceApi
 from extremecloudiq.api.device_api import DeviceApi
 from extremecloudiq.api.hiq_api import HIQApi
 from extremecloudiq.api.location_api import LocationApi
